@@ -9,16 +9,20 @@
 #include "akonadi-calendar_export.h"
 
 #include "itiphandler.h"
-#include <collection.h>
-#include <item.h>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
 #include <KCalendarCore/Incidence>
 
 #include <QWidget>
 
+#include <memory>
+
 namespace Akonadi
 {
 class EntityTreeModel;
+class IncidenceChangerPrivate;
+
 /**
  * @short IncidenceChanger is the preferred way to easily create, modify and delete incidences.
  *
@@ -140,7 +144,7 @@ public:
     /**
      * Destroys this IncidenceChanger instance.
      */
-    ~IncidenceChanger();
+    ~IncidenceChanger() override;
 
     /**
      * Creates a new incidence.
@@ -325,7 +329,7 @@ public:
 
     /**
      * Enable or disable history.
-     * With history enabled all changes are recored into the undo/redo stack.
+     * With history enabled all changes are recorded into the undo/redo stack.
      *
      * @see history()
      * @see historyEnabled()
@@ -349,7 +353,7 @@ public:
     History *history() const;
 
     /**
-     * For performance reasons, IncidenceChanger internaly caches the ids of the last deleted items,
+     * For performance reasons, IncidenceChanger internally caches the ids of the last deleted items,
      * to avoid creating useless delete jobs.
      *
      * This function exposes that functionality so it can be used in other scenarios.
@@ -445,12 +449,12 @@ Q_SIGNALS:
 
 private:
     //@cond PRIVATE
-    friend class History;
+    friend class HistoryPrivate;
     friend class AtomicOperation;
     // used internally by the History class
     explicit IncidenceChanger(bool enableHistory, QObject *parent = nullptr);
-    class Private;
-    Private *const d;
+
+    std::unique_ptr<IncidenceChangerPrivate> const d;
     //@endcond
 };
 }
