@@ -10,10 +10,10 @@
 #include <Akonadi/CollectionDialog>
 #include <KEMailSettings>
 #include <KEmailAddress>
+#include <KIdentityManagement/Identity>
+#include <KIdentityManagement/IdentityManager>
 #include <KIdentityManagement/Utils>
 #include <KMime/HeaderParsing>
-#include <identity.h>
-#include <identitymanager.h>
 
 #include <QPointer>
 #include <QWidget>
@@ -106,6 +106,6 @@ KCalendarCore::Incidence::Ptr Akonadi::CalendarUtils::incidence(const Akonadi::I
     try {
         return item.payload<KCalendarCore::Incidence::Ptr>();
     } catch (const Akonadi::PayloadException &) {
-        return KCalendarCore::Incidence::Ptr();
+        return {};
     }
 }
